/*
	File:		ASLMAssertionRules.r

	Contains:	Rules to set assertions.

	Copyright:	 1992-1994 by Apple Computer, Inc., all rights reserved.

*/

/**********************************************************************
** Rules to assert errors
***********************************************************************/

resource 'inrl' (rAssertNoSystemError)
{
	format0
	{{
		addAssertion{{aNoSystemError}}
	}};
};

#if GENERATING68K
	#if SYSTEM6
		resource 'inrl' (rAssertBadSystemError)
		{
			format0
			{{
				addAssertion{{aBadSystemError}}
			}};
		};

	#else
		resource 'inrl' (rAssertSystem7OnlyError)
		{
			format0
			{{
				addAssertion{{aSystem7OnlyError}}
			}};
		};
	#endif
#endif

#if GENERATINGPOWERPC && !GENERATING68K
	resource 'inrl' (rAssertPowerPCOn68KError)
	{
		format0
		{{
			addAssertion{{aPowerPCOn68KError}}
		}};
	};
#endif

/**********************************************************************
** Rule to determime of a later version of SLM is already installed
***********************************************************************/

#if GENERATING68K
	resource 'inrl' (rCheckForLater68kASLM)
	{
		format0
		{{
			checkFileVersion {fsTgtSharedLibraryManager, SLMCheckVersion},
			addAssertion{{aHasLater68kASLM}}
		}};
	};
#endif

#if GENERATINGPOWERPC
	resource 'inrl' (rCheckForLaterPPCASLM)
	{
		format0
		{{
			checkFileVersion {fsTgtSharedLibraryManagerPPC, SLMCheckVersion},
			checkAllAssertions {{aHasSystemPPC}},
			addAssertion{{aHasLaterPPCASLM}}
		}};
	};
#endif

/**********************************************************************
** Rule to determime if EtherTalk Phase 2 is already installed.
***********************************************************************/

resource 'inrl' (rCheckForEtherTalk)
{
	format0
	{{
		checkFileVersion {fsTrgEtherTalk, 0, 0, 0, 0},
		addAssertion{{aHasEtherTalk}}
	}};
};

resource 'inrl' (rCheckForEtherTalk2_0)
{
	format0
	{{
		checkFileVersion {fsTrgEtherTalk2_0, 0, 0, 0, 0},
		addAssertion{{aHasEtherTalk}}
	}};
};

resource 'inrl' (rCheckForEtherTalk2_1)
{
	format0
	{{
		checkFileVersion {fsTrgEtherTalk2_1, 0, 0, 0, 0},
		addAssertion{{aHasEtherTalk}}
	}};
};

resource 'inrl' (rCheckForEtherTalkPhase2)
{
	format0
	{{
		checkFileVersion {fsTrgEtherTalkPhase2, 0, 0, 0, 0},
		addAssertion{{aHasEtherTalk}}
	}};
};

/**********************************************************************
** Rules to determine the System version
***********************************************************************/

/*	-----------------------------------------------------------------
	Asserts 'aHasAnySystem' if any system file at all is present
	----------------------------------------------------------------- */

resource 'inrl' (rCheckForAnySystem) 
{
	format0
	{{
		checkFileVersion {fsSystemFile, 0, 0, 0, 0},
		addAssertion {{aHasAnySystem}}
	}};
};

#if GENERATING68K

	/*	-----------------------------------------------------------------
		Asserts 'aHasSystem6' if installng on System 6.0.5 or higher
		----------------------------------------------------------------- */
	
	resource 'inrl' (rCheckForSystem6) 
	{
		format0
		{{
			checkFileVersion {fsSystemFile, 6, 5, release, 0},
			addAssertion {{aHasSystem6, aHasSystem68k}}
		}};
	};
	
	/*	-----------------------------------------------------------------
		Asserts 'aHasSystem7' if installing on System 7.0 or higher
		----------------------------------------------------------------- */
	
	resource 'inrl' (rCheckForSystem7) 
	{
		format0
		{{
			checkFileVersion {fsSystemFile, 7, 0, release, 0},
			addAssertion {{aHasSystem7, aHasSystem68k}}
		}};
	};
	
	/*	-----------------------------------------------------------------
		Asserts 'aHasSystemAUX' installing on A/UX
		----------------------------------------------------------------- */
	
	resource 'inrl' (rCheckForSystemAUX) 
	{
		format0
		{{
			checkGestaltAttributes {'a/ux', 0xFFFFFFFF },
			addAssertion {{aHasSystemAUX, aHasSystem68k}}
		}};
	};

#endif

#if GENERATINGPOWERPC

	/*	-----------------------------------------------------------------
		Asserts 'aHasSystemPPC' installing on PowerPC
		----------------------------------------------------------------- */
	
	resource 'inrl' (rCheckForSystemPPC) 
	{
		format0
		{{
			checkGestalt {'sysa', { 2 } },
			addAssertion {{aHasSystemPPC }}
		}};
	};

#endif
