/*
	File:		ASLMAtoms.r

	Contains:	All resource, action, and file atoms use by the ASLM Installer.

	Copyright:	 1992-1994 by Apple Computer, Inc., all rights reserved.

*/

INCLUDE	"ShutdownActionAtom.RSRC" 'aatm' (0) as 'aatm' (0, $$Name, $$Attributes);
INCLUDE	"FixFmapActionAtom.RSRC" 'aatm' (0) as 'aatm' (1, $$Name, $$Attributes);

/**********************************************************************
** File atoms for the "EtherTalk Phase 2" file.
***********************************************************************/

resource 'infa' (faEtherTalkPhase2)
{
	format0
	{
		StdRemCopy,

		fsTrgEtherTalkPhase2,		/* target file spec id		*/
		fsSrcEtherTalkPhase2,		/* source file spec id		*/
		0,							/* atom size				*/
		"" 							/* Atom Name/Description	*/
	};
};

/**********************************************************************
** File atoms for the "Shared Library Manager" and 
** "Shared Library Manager PPC" files.
***********************************************************************/

#if GENERATING68K
	resource 'infa' (faSharedLibraryManager)
	{
		format0
		{
			StdRemCopy,
	
			fsTgtSharedLibraryManager,	/* target file spec id		*/
			fsSrcSharedLibraryManager,	/* source file spec id		*/
			0,							/* atom size				*/
			"" 							/* Atom Name/Description	*/
		};
	};
#endif

#if GENERATINGPOWERPC
	resource 'infa' (faSharedLibraryManagerPPC)
	{
		format0
		{
			StdRemCopy,
	
			fsTgtSharedLibraryManagerPPC,	/* target file spec id		*/
			fsSrcSharedLibraryManagerPPC,	/* source file spec id		*/
			0,								/* atom size				*/
			"" 								/* Atom Name/Description	*/
		};
	};
#endif

/**********************************************************************
** Action Atoms
***********************************************************************/

resource 'inaa' (aaShutDownActionAtom)
{
	format0
	{
		actBefore, actOnRemove, actOnInstall,
		'aatm',								/* resource type */
		0,									/* resource ID */
		0,									/* refcon */
		"Shutting down the Shared Library Manager",	/* installer message to user */
	};
};

resource 'inaa' (aaFixFmapActionAtom)
{
	format0
	{
		actBefore, dontActOnRemove, actOnInstall,
		'aatm',								/* resource type */
		1,									/* resource ID */
		0,									/* refcon */
		"",	/* installer message to user */
	};
};

/**********************************************************************
** Resource Atoms
***********************************************************************/

#if GENERATING68K
	resource 'inra' (raAddINIT19) 
	{
		format0 
		{
			StdRemResCopy,
			
			fsSystemFile,				/* Target File Spec			*/ 
			fsASLMResources,			/* Source File Spec			*/
			
			'INIT',						/* Resource Type			*/
			19,							/* Source ID				*/
			19,							/* Target ID				*/
			0,							/* Atom size				*/
			"",							/* Atom Name/Description	*/
			"",							/* Resource Name			*/
		};
	};

	resource 'inra' (raAddAINI32700) 
	{
		format0 
		{
			StdRemResCopy,
			
			fsSystemFile,				/* Target File Spec			*/ 
			fsASLMResources,			/* Source File Spec			*/
			
			'AINI',						/* Resource Type			*/
			-32700,						/* Source ID				*/
			-32700,						/* Target ID				*/
			0,							/* Resource size			*/
			"",							/* Atom Name/Description	*/
			"ASLM68KLoader",			/* Resource Name			*/
		};
	};
#endif

#if GENERATINGPOWERPC
	resource 'inra' (raAddAINI32702) 
	{
		format0 
		{
			StdRemResCopy,
	
			fsSystemFile,				/* Target File Spec			*/ 
			fsASLMResources,			/* Source File Spec			*/
			
			'AINI',						/* Resource Type			*/
			-32702,						/* Source ID				*/
			-32702,						/* Target ID				*/
			0,							/* Resource size			*/
			"ASLMPPCLoader",			/* Resource Name			*/
			"",							/* Atom Name/Description	*/
		};
	};
#endif

#if GENERATING68K
	resource 'inra' (raDeleteINIT17) 
	{
		format0 
		{
			StdResDelete,
			
			fsSystemFile,				/* Target File Spec			*/ 
			0,							/* Source File Spec			*/
			
			'INIT',						/* Resource Type			*/
			17,							/* Source ID				*/
			17,							/* Target ID				*/
			0,							/* Atom size				*/
			"",							/* Atom Name/Description	*/
			"",							/* Resource Name			*/
		};
	};

	resource 'inra' (raDeleteINIT19) 
	{
		format0 
		{
			StdResDelete,
			
			fsSystemFile,				/* Target File Spec			*/ 
			0,							/* Source File Spec			*/
			
			'INIT',						/* Resource Type			*/
			19,							/* Source ID				*/
			19,							/* Target ID				*/
			0,							/* Atom size				*/
			"",							/* Atom Name/Description	*/
			"",							/* Resource Name			*/
		};
	};
	
	resource 'inra' (raDeleteINIT22) 
	{
		format0 
		{
			StdResDelete,
			
			fsSystemFile,				/* Target File Spec			*/ 
			0,							/* Source File Spec			*/
			
			'INIT',						/* Resource Type			*/
			22,							/* Source ID				*/
			22,							/* Target ID				*/
			0,							/* Atom size				*/
			"",							/* Atom Name/Description	*/
			"",							/* Resource Name			*/
		};
	};
	
	resource 'inra' (raDeleteAINI1) 
	{
		format0 
		{
			StdResDelete,
			
			fsSystemFile,				/* Target File Spec			*/ 
			0,							/* Source File Spec			*/
			
			'AINI',						/* Resource Type			*/
			1,							/* Source ID				*/
			1,							/* Target ID				*/
			0,							/* Atom size				*/
			"",							/* Atom Name/Description	*/
			"",							/* Resource Name			*/
		};
	};
#endif

#if GENERATINGPOWERPC
	resource 'inra' (raDeleteAINI3) 
	{
		format0 
		{
			StdResDelete,
			
			fsSystemFile,				/* Target File Spec			*/ 
			0,							/* Source File Spec			*/
			
			'AINI',						/* Resource Type			*/
			3,							/* Source ID				*/
			3,							/* Target ID				*/
			0,							/* Atom size				*/
			"",							/* Atom Name/Description	*/
			"",							/* Resource Name			*/
		};
	};
	
	resource 'inra' (raDeleteAINI32698) 
	{
		format0 
		{
			StdResDelete,
			
			fsSystemFile,				/* Target File Spec			*/ 
			0,							/* Source File Spec			*/
			
			'AINI',						/* Resource Type			*/
			-32698,						/* Source ID				*/
			-32698,						/* Target ID				*/
			0,							/* Atom size				*/
			"",							/* Atom Name/Description	*/
			"",							/* Resource Name			*/
		};
	};
#endif
