/*
	File:		ASLMDefines.r

	Contains:	#defines for the ASLM Installer.

	Copyright:	 1991-1994 by Apple Computer, Inc., all rights reserved.

*/

#define SLMReleaseDate		Today

#ifndef SLMBase
	#define SLMBase				8000
#endif
#define IntlSLMBase						SLMBase+800

#ifndef InstallerDiskName
	#define InstallerDiskName	"ASLM Installer:"
#endif
#define SLMFolder	InstallerDiskName "Shared Library Manager Files:"

#ifndef SLMCustomShowFlag
	#define SLMCustomShowFlag	showsOnCustom
#endif

/*
** The version number below should be 1 higher than the current version
** number.
*/

#ifndef SLMCheckVersion
#define SLMCheckVersion		2, 0, beta, 6
#endif

#ifndef SLMCustomVersion
#define SLMCustomVersion	200
#endif

#ifndef INTERNATIONAL
	#define INTERNATIONAL	0
#endif

#if INTERNATIONAL
	#define USONLY	0
#else
	#define USONLY	1
#endif

#ifndef SYSTEM7ONLY
#define SYSTEM7ONLY		0
#endif

#if SYSTEM7ONLY
	#define SYSTEM6			0
#else
	#define SYSTEM6			1
#endif


/*******************************************************************************
** Defines for Resource ID's
********************************************************************************/

/*	-------------------------------------------------------------------------
	Assertions
	------------------------------------------------------------------------- */

#define aHasLater68kASLM				SLMBase+2
#define aHasLaterPPCASLM				SLMBase+3
#define	aHasEtherTalk					SLMBase+4

// Assertions that define what system we are installng onto

#define aHasAnySystem					SLMBase+10
#define aHasSystem68k					SLMBase+11
#define aHasSystem6						SLMBase+12
#define aHasSystem7						SLMBase+13
#define aHasSystemAUX					SLMBase+14
#define aHasSystemPPC					SLMBase+15

// Assertions to signal errors

#define aNoSystemError					SLMBase+20
#define aBadSystemError					SLMBase+21
#define aSystem7OnlyError				SLMBase+22
#define aPowerPCOn68KError				SLMBase+23

/*	-------------------------------------------------------------------------
	Rules
	------------------------------------------------------------------------- */

#define rCheckForLater68kASLM			SLMBase+101
#define rCheckForLaterPPCASLM			SLMBase+102
#define rCheckForEtherTalk				SLMBase+103
#define rCheckForEtherTalk2_0			SLMBase+104
#define rCheckForEtherTalk2_1			SLMBase+105
#define rCheckForEtherTalkPhase2		SLMBase+106

// Rules to set "system" assertions

#define rCheckForAnySystem				SLMBase+110
#define rCheckForSystem6				SLMBase+111
#define rCheckForSystem7				SLMBase+112
#define rCheckForSystemAUX				SLMBase+113
#define rCheckForSystemPPC				SLMBase+114

// Rules to set error detection assertions

#define rAssertNoSystemError			SLMBase+140
#define rAssertBadSystemError			SLMBase+141
#define rAssertSystem7OnlyError			SLMBase+142
#define rAssertPowerPCOn68KError		SLMBase+143

// Rules to report errors

#define rReportNoSystemError			SLMBase+150
#define rReportBadSystemError			SLMBase+151
#define rReportSystem7OnlyError			SLMBase+152
#define rReportPowerPCOn68KError		SLMBase+153
#define rReportNewerVersionError		SLMBase+154

// Rules to add Easy Install packages

#define rAddSystem6Package				SLMBase+120
#define rAddSystem7Package				SLMBase+121
#define rAddSystemAUXPackage			SLMBase+122
#define rAddSystemPPCPackage			SLMBase+123
#define rAddEtherTalkPackage			SLMBase+124

// Rules to add Custom Install packages

#define rAddSystem6CustomPackage		SLMBase+130
#define rAddSystem7CustomPackage		SLMBase+131
#define rAddSystemAUXCustomPackage		SLMBase+132
#define rAddSystemPPCCustomPackage		SLMBase+133
#define rAddEtherTalkCustomPackage		SLMBase+134

// Rules to add easy install descriptions

#define rAdd68kASLMDescription			SLMBase+160
#define rAddPPCASLMDescription			SLMBase+161
#define rAddClickDescription			SLMBase+162

/*	-------------------------------------------------------------------------
	Packages
	------------------------------------------------------------------------- */

// Top-level custom and easy install packages

#define pASLMForSystem6				SLMBase+200
#define pASLMForSystem7				SLMBase+201
#define pASLMForSystemAUX			SLMBase+202
#define pASLMForSystemPPC			SLMBase+203

// Packages that install the "Shared Library Manager" and 
// "Shared Library Manager PPC" files

#define p68kASLMFile				SLMBase+210
#define pPPCASLMFile				SLMBase+211

// Packages that install the proper ASLM loader resource(s)

#define pASLMSystem6Loader			SLMBase+220
#define pASLMSystem7Loader			SLMBase+221
#define pASLMSystemPPCLoader		SLMBase+222

// Package that installs the EtherTalk Phase 2 file

#define pAddEtherTalk				SLMBase+230

// Packages that run action atoms

#define pShutDownActionAtom		SLMBase+240
#define pFixFmapActionAtom		SLMBase+241

/*	-------------------------------------------------------------------------
	Atoms
	------------------------------------------------------------------------- */

// The "Shared Library Manager" & "Shared Library Manager PPC" files

#define faSharedLibraryManager		SLMBase+300
#define faSharedLibraryManagerPPC	SLMBase+301

// The ASLM loader resources in the "ASLM Resources" file

#define raAddAINI32700				SLMBase+310
#define raAddAINI32702				SLMBase+311
#define raAddINIT19					SLMBase+312

// Old ASLM loader resources that we want to delete

#define raDeleteINIT17				SLMBase+320
#define raDeleteINIT19				SLMBase+321
#define raDeleteINIT22				SLMBase+322
#define raDeleteAINI1				SLMBase+323
#define raDeleteAINI3				SLMBase+324
#define raDeleteAINI32698			SLMBase+325

// The EtherTalk Phase 2 file

#define faEtherTalkPhase2			SLMBase+330

// Action atoms

#define aaShutDownActionAtom		SLMBase+340
#define aaFixFmapActionAtom			SLMBase+341

/*	-------------------------------------------------------------------------
	Source and Target file specs
	------------------------------------------------------------------------- */

// The "Shared Library Manager" & "Shared Library Manager PPC" files

#define fsSrcSharedLibraryManager		SLMBase+400
#define fsSrcSharedLibraryManagerPPC	SLMBase+401
#define fsTgtSharedLibraryManager		SLMBase+402
#define fsTgtSharedLibraryManagerPPC	SLMBase+403

// The "System" file

#define fsSystemFile				SLMBase+410

// The "EtherTalk Phase 2" file

#define fsSrcEtherTalkPhase2		SLMBase+411
#define fsTrgEtherTalkPhase2		SLMBase+412

// Other EtherTalk files whose existence we check for

#define fsTrgEtherTalk				SLMBase+413
#define fsTrgEtherTalk2_0			SLMBase+414
#define fsTrgEtherTalk2_1			SLMBase+415

// The "ASLM Resources" file

#define fsASLMResources				SLMBase+420

/*	-------------------------------------------------------------------------
	Icons
	------------------------------------------------------------------------- */

#define ASLMIcon					SLMBase+500


/**********************************************************************
** Some Defines to make things more readable
***********************************************************************/

#ifndef StdLeaveNewerCopy
#define StdLeaveNewerCopy		dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								leaveAloneIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork	
#endif

#ifndef StdCopy
#define StdCopy					dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								updateEvenIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork	
#endif

#ifndef StdRemLeaveNewerCopy
#define StdRemLeaveNewerCopy	deleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								leaveAloneIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork	
#endif

#ifndef StdRemCopy
#define StdRemCopy				deleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								updateEvenIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork	
#endif

#ifndef StdDelete
#define StdDelete				deleteWhenRemoving,		\
								deleteWhenInstalling,	\
								dontCopy,				\
								updateEvenIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork
#endif

#ifndef StdResCopy
#define StdResCopy				dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byID,					\
								nameNeedNotMatch
#endif

#ifndef StdRemResCopy
#define StdRemResCopy			deleteWhenRemoving,		\
								deleteWhenInstalling,	\
								copy,					\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byID,					\
								nameNeedNotMatch
#endif

#ifndef StdRemResCopy1
#define StdRemResCopy1			deleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								leaveAloneIfNewer,		\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byID,					\
								nameNeedNotMatch
#endif

#ifndef StdResMake
#define StdResMake				dontDeleteWhenRemoving,		\
								dontDeleteWhenInstalling,	\
								copy,					\
								noTgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byID,					\
								nameNeedNotMatch
#endif

#ifndef StdResCopyName
#define StdResCopyName			dontDeleteWhenRemoving,	\
								dontDeleteWhenInstalling,	\
								copy,					\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byID,					\
								nameMustMatch
#endif

#ifndef StdResDelete
#define StdResDelete			deleteWhenRemoving,		\
								deleteWhenInstalling,	\
								dontCopy,				\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								ignoreProtection,		\
								srcNeedNotExist,		\
								byID,					\
								nameNeedNotMatch
#endif
