/*
	File:		ASLMPackages.r

	Contains:	All packages used by the ASLM Installer

	Copyright:	 1994 by Apple Computer, Inc., all rights reserved.

*/

/**********************************************************************
** Icons referenced by packages
***********************************************************************/

resource 'ICON' (ASLMIcon)
{
		$"003F FC00 0040 0200 0020 0400 7FF0 0FFE"
		$"8000 0001 8038 0001 8047 0001 8082 E001"
		$"8111 5001 83FC AFC1 8602 A841 BA02 A841"
		$"B201 6841 B200 1041 B200 0041 B200 005D"
		$"BE00 007D BA00 004D 8200 004D 8208 004D"
		$"8216 804D 8215 405D 8215 4061 83F5 3FC1"
		$"800A 8081 8005 0101 8002 FE01 8000 0001"
		$"807F FE01 8080 0101 8040 0201 7FE0 07FE",
};

/*******************************************************************************
** Top level packages for Easy Install and Custom Install
********************************************************************************/

/*	-----------------------------------------------------------------
	Package to install the EtherTalk Phase 2 file.
	----------------------------------------------------------------- */

resource 'icmt' (pAddEtherTalk) 
{
	SLMReleaseDate,									/* Release Date	*/
	SLMCustomVersion,
	ASLMIcon,										/* Icon ID		*/
	"The EtherTalk Phase 2 file is needed when installing onto a"
	" machine that has a minimal System 7.x installed."
};

resource 'inpk' (pAddEtherTalk) 
{
	format0 
	{
		showsOnCustom,
		notremovable,				/* Package cannot be removed		*/
		forceRestart,				/* Package should force restart		*/
		pAddEtherTalk,				/* ICMT ID							*/
		0,							/* Package size						*/
		"EtherTalk Phase 2 file",
		{
			'infa',	faEtherTalkPhase2;
		}
	}
};

#if GENERATING68K

	/*	-----------------------------------------------------------------
		System 6 Installation Package.
		----------------------------------------------------------------- */
	
	resource 'icmt' (pASLMForSystem6) 
	{
		SLMReleaseDate,									/* Release Date	*/
		SLMCustomVersion,
		ASLMIcon,										/* Icon ID		*/
		"This installs the Shared Library Manager file"
		" into the System 6 System folder for 68k ASLM support."
		" Two resources are also installed into the System file."
	};
	
	resource 'inpk' (pASLMForSystem6)
	{
		format0 
		{
			showsOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should not force restart	*/
			pASLMForSystem6,			/* ICMT ID							*/
			0,							/* Package size						*/
			"Apple Shared Library Manager for 68k",
			{
				'inpk', pShutDownActionAtom;
				'inpk', pFixFmapActionAtom;
				'inpk', pASLMSystem6Loader;
				'inpk', p68kASLMFile;
			}
		}
	};
	
	/*	-----------------------------------------------------------------
		System 7 Installation Package.
		----------------------------------------------------------------- */
	
	resource 'icmt' (pASLMForSystem7) 
	{
		SLMReleaseDate,									/* Release Date	*/
		SLMCustomVersion,
		ASLMIcon,										/* Icon ID		*/
		"This installs the Shared Library Manager file"
		" into the System 7 Extensions folder for 68k ASLM support."
		" One resource is also installed into the System file."
	};
	
	resource 'inpk' (pASLMForSystem7)
	{
		format0 
		{
			showsOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should force restart		*/
			pASLMForSystem7,				/* ICMT ID							*/
			0,							/* Package size						*/
			"Apple Shared Library Manager for 68k",
			{
				'inpk', pShutDownActionAtom;
				'inpk', pFixFmapActionAtom;
				'inpk', pASLMSystem7Loader;
				'inpk', p68kASLMFile;
			}
		}
	};
	
	/*	-----------------------------------------------------------------
		A/UX Installation Package.
		----------------------------------------------------------------- */
	
	resource 'icmt' (pASLMForSystemAUX) 
	{
		SLMReleaseDate,									/* Release Date	*/
		SLMCustomVersion,
		ASLMIcon,										/* Icon ID		*/
		"This installs the Shared Library Manager file"
		" into the System 7 Extensions folder for 68k ASLM support."
		" Two resources are also installed into the System file."
	};
	
	resource 'inpk' (pASLMForSystemAUX)
	{
		format0 
		{
			showsOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should force restart		*/
			pASLMForSystemAUX,			/* ICMT ID							*/
			0,							/* Package size						*/
			"Apple Shared Library Manager for 68k",
			{
				'inpk', pShutDownActionAtom;
				'inpk', pFixFmapActionAtom;
				'inpk', pASLMSystem6Loader;
				'inpk', p68kASLMFile;
			}
		}
	};

#endif

#if GENERATINGPOWERPC

	/*	-----------------------------------------------------------------
		PowerPC Installation Package.
		----------------------------------------------------------------- */
	
	resource 'icmt' (pASLMForSystemPPC) 
	{
		SLMReleaseDate,									/* Release Date	*/
		SLMCustomVersion,
		ASLMIcon,										/* Icon ID		*/
		"This installs the Shared Library Manager PPC file"
		" into the Extensions folder for PowerPC ASLM support."
		" One resource is also installed into the System file. "
	};
	
	resource 'inpk' (pASLMForSystemPPC)
	{
		format0 
		{
			showsOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should force restart		*/
			pASLMForSystemPPC,			/* ICMT ID							*/
			0,							/* Package size						*/
			"Apple Shared Library Manager for PowerPC",
			{
				'inpk', pShutDownActionAtom;
				'inpk', pFixFmapActionAtom;
				'inpk', pASLMSystemPPCLoader;		/* Install PowerPC Loader		*/
				'inpk', pPPCASLMFile;				/* Install PowerPC SLM	 file	*/
			}
		}
	};

#endif

/**********************************************************************
** Action atom packages
***********************************************************************/
	
/*	-----------------------------------------------------------------
	Package to call the ShutDown action atom.
	----------------------------------------------------------------- */

resource 'inpk' (pShutDownActionAtom) 
{
	format0 
	{
		doesntShowOnCustom,
		removable,					/* Package can be removed			*/
		forceRestart,				/* Package should force restart		*/
		0,							/* ICMT ID							*/
		0,							/* Package size						*/
		"ShutDown Action Atom",
		{
			'inaa',	aaShutDownActionAtom;
		}
	}
};
	
/*	-----------------------------------------------------------------
	Package to call the FixFMap action atom.
	----------------------------------------------------------------- */

resource 'inpk' (pFixFmapActionAtom) 
{
	format0 
	{
		doesntShowOnCustom,
		notRemovable,				/* Package cannot be removed		*/
		forceRestart,				/* Package should force restart		*/
		0,							/* ICMT ID							*/
		0,							/* Package size						*/
		"FixFmap Action Atom",
		{
			'inaa',	aaFixFmapActionAtom;
		}
	}
};

/**********************************************************************
** Packages to install the ASLM Loader resource ('AINI' and/or 'INIT')
***********************************************************************/

#if GENERATING68K
	/*	-----------------------------------------------------------------
		Package to install the the 68k ASLM AINI and INIT resources.
		for System 6 and for a/ux.
		----------------------------------------------------------------- */
	
	resource 'inpk' (pASLMSystem6Loader) 
	{
		format0 
		{
			doesntShowOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should force restart		*/
			0,							/* ICMT ID							*/
			0,							/* Package size						*/
			"",
			{
				'inra',	raAddAINI32700;
				'inra',	raAddINIT19;
				'inra',	raDeleteAINI1;
				'inra',	raDeleteINIT17;
				'inra',	raDeleteINIT22;
			}
		}
	};
	
	/*	-----------------------------------------------------------------
		Package to install the 68k ASLM AINI resource for System 7.
		----------------------------------------------------------------- */
	
	resource 'inpk' (pASLMSystem7Loader) 
	{
		format0 
		{
			doesntShowOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should force restart		*/
			0,							/* ICMT ID							*/
			0,							/* Package size						*/
			"",
			{
				'inra',	raAddAINI32700;
				'inra',	raDeleteAINI1;
				'inra',	raDeleteINIT17;
				'inra',	raDeleteINIT19;
				'inra',	raDeleteINIT22;
			}
		}
	};
#endif

#if GENERATINGPOWERPC
	/*	-----------------------------------------------------------------
		Package to install the PowerPC ASLM AINI resource for PowerPC systems.
		----------------------------------------------------------------- */
	
	resource 'inpk' (pASLMSystemPPCLoader) 
	{
		format0 
		{
			doesntShowOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should force restart		*/
			0,							/* ICMT ID							*/
			0,							/* Package size						*/
			"",
			{
				'inra',	raAddAINI32702;
				'inra',	raDeleteAINI3;
				'inra',	raDeleteAINI32698;
			}
		}
	};
#endif

/**********************************************************************
** Packages to install the Shared Library Manager and
** Shared Library Manager PPC files.
***********************************************************************/

#if GENERATING68K
	resource 'inpk' (p68kASLMFile) 
	{
		format0 
		{
			doesntShowOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should force restart		*/
			0,							/* ICMT ID							*/
			0,							/* Package size						*/
			"",
			{
				'infa',	faSharedLibraryManager;
			}
		}
	};
#endif
	
#if GENERATINGPOWERPC
	resource 'inpk' (pPPCASLMFile) 
	{
		format0 
		{
			doesntShowOnCustom,
			removable,					/* Package can be removed			*/
			forceRestart,				/* Package should force restart		*/
			0,							/* ICMT ID							*/
			0,							/* Package size						*/
			"",
			{
				'infa',	faSharedLibraryManagerPPC;
			}
		}
	};
#endif
